@@ -1,19 +1,19 @@
 require 'eventmachine'
-require 'escape_utils'
+require 'em-socksify'
 require 'addressable/uri'
+require 'http/parser'
 
 require 'base64'
 require 'socket'
 
-require 'http11_client'
-require 'em_buffer'
-
 require 'em-http/core_ext/bytesize'
+require 'em-http/http_connection'
 require 'em-http/http_header'
 require 'em-http/http_encoding'
-require 'em-http/http_options'
+require 'em-http/http_status_codes'
+require 'em-http/http_client_options'
+require 'em-http/http_connection_options'
 require 'em-http/client'
 require 'em-http/multi'
 require 'em-http/request'
 require 'em-http/decoders'
-require 'em-http/mock'
\ No newline at end of file
