@@ -21,7 +21,7 @@ module EventMachine
 
     CRLF="\r\n"
 
-    attr_accessor :state, :response
+    attr_accessor :state, :response, :conn
     attr_reader   :response_header, :error, :content_charset, :req, :cookies
 
     def initialize(conn, options)
@@ -100,14 +100,13 @@ module EventMachine
 
               @cookies.clear
               @cookies = @cookiejar.get(@response_header.location).map(&:to_s) if @req.pass_cookies
-              @req.set_uri(@response_header.location)
 
-              @conn.redirect(self)
+              @conn.redirect(self, @response_header.location)
             else
               succeed(self)
             end
 
-          rescue Exception => e
+          rescue => e
             on_error(e.message)
           end
         else
@@ -156,11 +155,16 @@ module EventMachine
 
       # Set the User-Agent if it hasn't been specified
       if !head.key?('user-agent')
-        head['user-agent'] = "EventMachine HttpClient"
+        head['user-agent'] = 'EventMachine HttpClient'
       elsif head['user-agent'].nil?
         head.delete('user-agent')
       end
 
+      # Set the Accept-Encoding header if none is provided
+      if !head.key?('accept-encoding') && req.compressed
+        head['accept-encoding'] = 'gzip, compressed'
+      end
+
       # Set the auth from the URI if given
       head['Authorization'] = @req.uri.userinfo.split(/:/, 2) if @req.uri.userinfo
 
@@ -189,7 +193,7 @@ module EventMachine
         head['content-type'] = 'application/x-www-form-urlencoded'
       end
 
-      request_header ||= encode_request(@req.method, @req.uri, query, @conn.connopts.proxy)
+      request_header ||= encode_request(@req.method, @req.uri, query, @conn.connopts)
       request_header << encode_headers(head)
       request_header << CRLF
       @conn.send_data request_header
