@@ -51,7 +51,7 @@ describe EventMachine::HttpRequest do
     EventMachine.run {
       lambda {
       EventMachine::HttpRequest.new('random?text').get
-    }.should raise_error
+    }.should raise_error(Addressable::URI::InvalidURIError)
 
     EM.stop
     }
@@ -386,7 +386,7 @@ describe EventMachine::HttpRequest do
     }
   end
 
-  it "should detect gzip encoding" do
+  it "should auto-detect and decode gzip encoding" do
     EventMachine.run {
 
       http = EventMachine::HttpRequest.new('http://127.0.0.1:8090/gzip').get :head => {"accept-encoding" => "gzip, compressed"}
@@ -446,6 +446,36 @@ describe EventMachine::HttpRequest do
     }
   end
 
+  it "should default to requesting compressed response" do
+    EventMachine.run {
+
+      http = EventMachine::HttpRequest.new('http://127.0.0.1:8090/echo_accept_encoding').get
+
+      http.errback { failed(http) }
+      http.callback {
+        http.response_header.status.should == 200
+        http.response.should == "gzip, compressed"
+
+        EventMachine.stop
+      }
+    }
+  end
+
+  it "should default to requesting compressed response" do
+    EventMachine.run {
+
+      http = EventMachine::HttpRequest.new('http://127.0.0.1:8090/echo_accept_encoding').get :compressed => false
+
+      http.errback { failed(http) }
+      http.callback {
+        http.response_header.status.should == 200
+        http.response.should == ""
+
+        EventMachine.stop
+      }
+    }
+  end
+
   it "should timeout after 0.1 seconds of inactivity" do
     EventMachine.run {
       t = Time.now.to_i
@@ -848,6 +878,33 @@ describe EventMachine::HttpRequest do
     }
   end
 
+  it "should close connection on invalid HTTP response" do
+    EventMachine.run {
+      response =<<-HTTP.gsub(/^ +/, '').strip
+        HTTP/1.1 403 Forbidden
+        Content-Type: text/plain
+        Content-Length: 13
+
+        Access Denied
+
+        HTTP/1.1 403 Forbidden
+        Content-Type: text/plain
+        Content-Length: 13
+
+        Access Denied
+      HTTP
+
+      @s = StubServer.new(response)
+      lambda {
+        conn = EventMachine::HttpRequest.new('http://127.0.0.1:8081/')
+        req = conn.get
+        req.errback { failed(http) }
+        req.callback { EM.stop }
+      }.should_not raise_error
+
+    }
+  end
+
   context "User-Agent" do
     it 'should default to "EventMachine HttpClient"' do
       EventMachine.run {
