@@ -17,7 +17,7 @@ module Stallion
 
     def match?(request)
       method = request['REQUEST_METHOD']
-      right_method = @methods.empty? or @methods.include?(method)
+      @methods.empty? or @methods.include?(method)
     end
   end
 
@@ -36,7 +36,7 @@ module Stallion
 
     def call(request, response)
       @request, @response = request, response
-      @boxes.each do |(path, methods), mount|
+      @boxes.each do |_, mount|
         if mount.match?(request)
           mount.ride
         end
@@ -96,6 +96,9 @@ Stallion.saddle :spec do |stable|
     elsif stable.request.path_info == '/echo_content_length_from_header'
       stable.response.write "content-length:#{stable.request.env["CONTENT_LENGTH"]}"
 
+    elsif stable.request.path_info == '/echo_authorization_header'
+      stable.response.write "authorization:#{stable.request.env["HTTP_AUTHORIZATION"]}"
+
     elsif stable.request.head? && stable.request.path_info == '/'
       stable.response.status = 200
 
@@ -201,6 +204,14 @@ Stallion.saddle :spec do |stable|
       stable.response.status = 301
       stable.response["Location"] = "https://host:443/"
 
+    elsif stable.request.path_info == '/redirect/ignore_query_option'
+      stable.response.status = 301
+      stable.response['Location'] = '/redirect/url'
+
+    elsif stable.request.path_info == '/redirect/url'
+      stable.response.status = 200
+      stable.response.write stable.request.url
+
     elsif stable.request.path_info == '/gzip'
       io = StringIO.new
       gzip = Zlib::GzipWriter.new(io)
@@ -227,6 +238,10 @@ Stallion.saddle :spec do |stable|
       stable.response.write deflater.finish
       stable.response["Content-Encoding"] = "deflate"
 
+    elsif stable.request.path_info == '/echo_accept_encoding'
+      stable.response.status = 200
+      stable.response.write stable.request.env["HTTP_ACCEPT_ENCODING"]
+
     elsif stable.request.env["HTTP_IF_NONE_MATCH"]
       stable.response.status = 304
 
@@ -234,7 +249,7 @@ Stallion.saddle :spec do |stable|
       stable.response.status = 200
       stable.response.write stable.request.env["HTTP_AUTHORIZATION"]
     elsif stable.request.path_info == '/authtest'
-      auth = "Basic %s" % Base64.encode64(['user', 'pass'].join(':')).split.join
+      auth = "Basic %s" % Base64.strict_encode64(['user', 'pass'].join(':')).split.join
       if auth == stable.request.env["HTTP_AUTHORIZATION"]
         stable.response.status = 200
         stable.response.write 'success'
@@ -257,7 +272,7 @@ end
 Thread.new do
   begin
     Stallion.run :Host => '127.0.0.1', :Port => 8090
-  rescue Exception => e
+  rescue => e
     print e
   end
 end
